"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkUpdates = void 0;
const latest_version_1 = __importDefault(require("latest-version"));
const semver_1 = require("../utils/semver");
const boxen_1 = __importDefault(require("boxen"));
const { version } = require('../../../package.json');
const chalk = require('chalk');
let updatesChecked = false;
function checkUpdates() {
    return __awaiter(this, void 0, void 0, function* () {
        if (!updatesChecked) {
            updatesChecked = true;
            return yield checkVenomVersion();
        }
    });
}
exports.checkUpdates = checkUpdates;
function checkVenomVersion() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield (0, latest_version_1.default)('hydra-bot').then((latest) => {
                if ((0, semver_1.upToDate)(version, latest)) {
                    console.log("You're up to date");
                }
                else {
                    console.log('There is a new version available');
                    logUpdateAvailable(version, latest);
                }
            });
        }
        catch (_a) {
            console.log('Unable to access: "https://www.npmjs.com", check your internet');
            return false;
        }
    });
}
function logUpdateAvailable(current, latest) {
    // prettier-ignore
    const newVersionLog = `There is a new version of ${chalk.bold(`hydra`)} ${chalk.gray(current)} ➜  ${chalk.bold.green(latest)}\n` +
        `Update your package by running:\n\n` +
        `${chalk.bold('\>')} ${chalk.blueBright('npm update hydra-bot')}`;
    console.log((0, boxen_1.default)(newVersionLog, { padding: 1 }));
    console.log(`For more info visit: ${chalk.underline('https://github.com/jonalan7/Hydra-bot/blob/master/Update.md')}\n`);
}
//# sourceMappingURL=check-up-to-date.js.map